@@ -1,9 +1,10 @@
-from django.db.models import Field
-from redactor.widgets import RedactorEditor
+from django.db.models import TextField
 from django.conf import settings
+from django.contrib.admin import widgets as admin_widgets
+from redactor.widgets import RedactorEditor
 
 
-class RedactorField(Field):
+class RedactorField(TextField):
     def __init__(self, *args, **kwargs):
         options = kwargs.pop('redactor_options', {})
         upload_to = kwargs.pop('upload_to', '')
@@ -17,12 +18,12 @@ class RedactorField(Field):
         )
         super(RedactorField, self).__init__(*args, **kwargs)
 
-    def get_internal_type(self):
-        return "TextField"
-
     def formfield(self, **kwargs):
         defaults = {'widget': self.widget}
         defaults.update(kwargs)
+
+        if defaults['widget'] == admin_widgets.AdminTextareaWidget:
+            defaults['widget'] = self.widget
         return super(RedactorField, self).formfield(**defaults)
 
 
