@@ -10,11 +10,11 @@ from redactor.forms import FileForm, ImageForm
 
 urlpatterns = patterns(
     '',
-    url('^upload/image/(?P<upload_to>.*)',
+    url(r'^upload/image/(?P<upload_to>.*)',
         RedactorUploadView.as_view(form_class=ImageForm),
         name='redactor_upload_image'),
 
-    url('^upload/file/(?P<upload_to>.*)',
+    url(r'^upload/file/(?P<upload_to>.*)',
         RedactorUploadView.as_view(form_class=FileForm),
         name='redactor_upload_file'),
 )
